# Technology-Note
Learn the techniques developed in Python

## Install
```
python -m pip install Technology-Note
```

## Docs

- [Wiki](https://github.com/CoolPlayLin/Technology-Note/wiki)
- [Changelog](./Update.md)